import { Component, Input, ViewChild } from "@angular/core";
import { FeedbackModalComponent } from "./feedback-modal.component";
import { FeedbackService } from "./feedback.service";
var FeedbackComponent = (function () {
    function FeedbackComponent(feedback) {
        this.feedback = feedback;
        this.isHidden = false;
        this.isLoading = false;
        this.isScreenshotMode = false;
        feedback.buttonComponent = this;
    }
    /**
     * Cancel taking of screenshot.
     */
    FeedbackComponent.prototype.cancelScreenshot = function () {
        if (this.configuration.onCancelScreenshot) {
            this.configuration.onCancelScreenshot();
        }
        this.isScreenshotMode = false;
        this.feedbackModal.openModal();
        this.feedback.destroyCanvas();
    };
    /**
     * Clear screenshots.
     */
    FeedbackComponent.prototype.clearScreenshots = function () {
        this.feedback.clearScreenshots();
    };
    /**
     * Get all screenshots taken.
     * @return {string[]} the screenshots as dataUrls.
     */
    FeedbackComponent.prototype.getScreenshots = function () {
        return this.feedback.getScreenshots();
    };
    /**
     * Open feedback modal.
     */
    FeedbackComponent.prototype.openFeedbackModal = function () {
        if (this.configuration.onOpen) {
            this.configuration.onOpen();
        }
        this.isHidden = true;
        this.feedbackModal.openModal();
    };
    /**
     * Take a screenshot.
     */
    FeedbackComponent.prototype.takeScreenshot = function () {
        this.feedback.takeScreenshot();
    };
    return FeedbackComponent;
}());
export { FeedbackComponent };
FeedbackComponent.decorators = [
    { type: Component, args: [{
                selector: "ngx-bootstrap-feedback",
                template: "<div class=\"send-feedback btn btn-default-lt\" [ngClass]=\"{hidden: isHidden}\">\n  <!--- SEND FEEDBACK -->\n  <div *ngIf=\"!isScreenshotMode\" (click)=\"openFeedbackModal()\">\n    {{configuration.feedbackButtonText ? configuration.feedbackButtonText : \"Send Feedback\"}}\n    <span class=\"glyphicon glyphicon-comment\" aria-hidden=\"true\"></span>\n  </div>\n  <!--- /SEND FEEDBACK -->\n  <!-- SCREENSHOT OPTIONS -->\n  <div *ngIf=\"isScreenshotMode\">\n    <span>Options</span>\n    <div class=\"row\">\n      <div class=\"col-xs-12\">\n        <button class=\"btn btn-primary btn-feedback col-xs-12\"\n                [attr.disabled]=\"isLoading ? true : null\"\n                (click)=\"takeScreenshot()\"\n                [ngClass]=\"{'m-progress': isLoading}\">\n          {{configuration.takeScreenshotButtonText ? configuration.takeScreenshotButtonText : \"Take Screenshot\"}}\n        </button>\n      </div>\n    </div>\n    <div class=\"row\">\n      <div class=\"col-xs-12\">\n        <button class=\"btn btn-default btn-feedback col-xs-12\"\n                [attr.disabled]=\"isLoading ? true : null\"\n                (click)=\"cancelScreenshot()\">\n          {{configuration.cancelScreenshotButtonText ? configuration.cancelScreenshotButtonText : \"Cancel\"}}\n        </button>\n      </div>\n    </div>\n  </div>\n  <!-- /SCREENSHOT OPTIONS -->\n</div>\n<ngx-bootstrap-feedback-modal [configuration]=\"configuration\">\n  <ng-content></ng-content>\n</ngx-bootstrap-feedback-modal>\n"
            },] },
];
/** @nocollapse */
FeedbackComponent.ctorParameters = function () { return [
    { type: FeedbackService, },
]; };
FeedbackComponent.propDecorators = {
    'feedbackModal': [{ type: ViewChild, args: [FeedbackModalComponent,] },],
    'configuration': [{ type: Input },],
};
//# sourceMappingURL=feedback.component.js.map